# SPDX-FileCopyrightText: 2019-2025 Valéry Febvre
# SPDX-License-Identifier: GPL-3.0-or-later
# Author: Valéry Febvre <vfebvre@easter-eggs.com>

from komikku.servers.multi.heancms import HeanCMS


class Hijalascans(HeanCMS):
    id = 'hijalascans'
    name = 'Hijala Scans'
    lang = 'en'

    base_url = 'https://en-hijala.com'
    logo_url = 'https://storage.en-hijala.com/upload/2025/06/24/final-523b7e2e4fb3a659.webp'
    api_url = 'https://api.en-hijala.com/api'



# SPDX-FileCopyrightText: 2019-2026 Valéry Febvre
# SPDX-License-Identifier: GPL-3.0-or-later
# Author: Valéry Febvre <vfebvre@easter-eggs.com>

import datetime

COVER_WIDTH = 180
COVER_HEIGHT = 256
LOGO_SIZE = 32
MISSING_IMG_RESOURCE_PATH = '/info/febvre/Komikku/images/missing_file.png'

DOWNLOAD_MAX_DELAY = 1  # in seconds
REQUESTS_TIMEOUT = 5
USER_AGENT = 'Mozilla/5.0 (X11; Linux x86_64; rv:129.0) Gecko/20100101 Firefox/129.0'
USER_AGENT_MOBILE = 'Mozilla/5.0 (Linux; U; Android 4.1.1; en-gb; Build/KLP) AppleWebKit/534.30 (KHTML, like Gecko) Version/4.0 Safari/534.30'

TIMEZONE = datetime.datetime.now(tz=datetime.UTC).astimezone().tzinfo

CREDITS = dict(
    artists=(
        'Tobias Bernard (bertob)',
    ),
    designers=(
        'Tobias Bernard (bertob)',
        'Valéry Febvre (valos)',
    ),
    developers=(
        'Mufeed Ali (fushinari)',
        'Gerben Droogers (Tijder)',
        'Valéry Febvre (valos)',
        'Aurélien Hamy (aunetx)',
        'Amelia Joison (amnetrine)',
        'David Keller (BlobCodes)',
        'Oleg Kiryazov (CakesTwix)',
        'Lili Kurek',
        'Liliana Prikler',
        'Sabri Ünal',
        'Romain Vaudois',
        'Arthur Williams (TAAPArthur)',
        'GrownNed',
        'ISO-morphism',
        'jaskaranSM',
    ),
    translators=(
        'abidin toumi (Arabic)',
        'Rayen Ghanmi (Arabic)',
        'Mohamed Abdalah Noh (Arabic)',
        'Ahmed Najmawi (Arabic)',
        'Rafael Fontenelle (Brazilian Portuguese)',
        'Infinitive Witch (Brazilian Portuguese)',
        'Unidealistic Raccoon (Brazilian Portuguese)',
        'Alex Carvalho (Brazilian Portuguese)',
        'Juliano de Souza Camargo (Brazilian Portuguese)',
        'Giovanne Menicheli (Brazilian Portuguese)',
        'Fúlvio Alves (Brazilian Portuguese)',
        'Felipe (Brazilian Portuguese)',
        'Matheus Santana (Brazilian Portuguese)',
        'Lucas Oliveira (Brazilian Portuguese)',
        'Lucas Loura (Brazilian Portuguese)',
        'Beruto666 (Brazilian Portuguese)',
        'twlvnn (Bulgarian)',
        'Roger VC (Catalan)',
        'Lukáš Linhart (Czech)',
        'Jakub Soukup (Czech)',
        'Petr Horník (Czech)',
        'Dingzhong Chen (Simplified Chinese)',
        'Eric-Song-Nop (Simplified Chinese)',
        'Inaha (Simplified Chinese)',
        'LS-Shandong (Simplified Chinese)',
        'randint (Traditional Chinese)',
        'Zhao Se (Traditional Chinese)',
        'happylittle7 (Traditional Chinese)',
        'Heimen Stoffels (Dutch)',
        'Philip Goto (Dutch)',
        'Koen Benne (Dutch)',
        'Mikachu (Dutch)',
        'Danial Behzadi (Persian)',
        'Muhammad Hussein Ammari (Persian)',
        'Jiri Grönroos (Finnish)',
        'Ricky Tigg (Finnish)',
        'Irénée THIRION (French)',
        'Valéry Febvre (French)',
        'Mathieu B. (French)',
        'rene-coty (French)',
        'paul verot (French)',
        'Sandor Odor (German)',
        'Liliana Prikler (German)',
        'gregorni (German)',
        'Liliana Marie Prikler (German)',
        'Tim (German)',
        'Sear Gasor (German)',
        'Vortex Acherontic (German)',
        'Dlurak (German)',
        'Mirko P. (German)',
        'Simon Barth (German)',
        'anon (German)',
        'Scrambled777 (Hindi)',
        'Milo Ivir (Croatian)',
        'Alifiyan Rosyidi (Indonesian)',
        'Alim Satria (Indonesian)',
        'Juan Manuel (Indonesian)',
        'srntskl-111 (Indonesian)',
        'Nataniel Dika Kurniawan (Indonesian)',
        'Mek101 (Italian)',
        'dedocc (Italian)',
        'Davide Mora (Italian)',
        'Andrea Scarano (Italian)',
        'pasquale ruotolo (Italian)',
        'Riccardo Luise (Italian)',
        'cas9 (Italian)',
        'Giulia (Italian)',
        '안세훈 (Korean)',
        'Flynn (Cornish)',
        'Velyvis (Lithuanian)',
        'Lili Kurek (Polish)',
        'Aleksander Warzyniak (Polish)',
        'Kurai (Polish)',
        'ssantos (Portuguese)',
        'Ademario Cunha (Portuguese)',
        'SpiralPack 527 (Portuguese)',
        'Lucas Silva Goulart (Portuguese)',
        'Manuela Silva (Portuguese)',
        'shima (Russian)',
        'Valentin Chernetsov (Russian)',
        'FIONover (Russian)',
        'Анна Алешкина #нетвойне (Russian)',
        'Сергей (Russian)',
        'Óscar Fernández Díaz (Spanish)',
        'gallegonovato (Spanish)',
        'Klauss (Spanish)',
        'Jesper (Swedish)',
        'PaneradFisk (Swedish)',
        'Willem Dinkelspiel (Swedish)',
        'Daniel Wiik (Swedish)',
        'தமிழ்நேரம் (Tamil)',
        'Ege Çelikçi (Turkish)',
        'Sabri Ünal (Turkish)',
        'Volkan Yıldırım (Turkish)',
        'Efe Akın (Turkish)',
        'Ahmet (Turkish)',
        'CakesTwix (Ukrainian)',
        'Kislotniy (Acela) (Ukrainian)',
        'mondstern (Ukrainian)',
        'DXCVII (Ukrainian)',
        'Bezruchenko Simon (Ukrainian)',
        'Максим Горпиніч (Ukrainian)',
        'Димко (Ukrainian)',
        'niyaki hayyashi (Vietnamese)',
        'Loc Huynh (Vietnamese)',
    ),
    supporters=(
        'gondolyr',
        'José',
    ),
)

RELEASE_NOTES = """
<ul>
    <li>[Card] Improved `Blurred covers` backdrop</li>
    <li>[Card] Info: Added the time to `Last Update`</li>
    <li>[Reader] Improved notification message when an image fails to load (unidentified)</li>
    <li>[Reader] Improved saving of reading progress</li>
    <li>[Servers] Added Suwayomi</li>
    <li>[Servers] Comix (EN): Update</li>
    <li>[Servers] EZmanga (EN): Update</li>
    <li>[Servers] MangaDex: Get manga chapters regardless of content rating</li>
    <li>[Servers] MangaNato (EN): Update</li>
    <li>[Servers] Qi Scans (EN): Update</li>
    <li>[Servers] WeebDex (multi): Update</li>
    <li>[L10n] Updated Croatian, French, German, Korean and Ukrainian translations</li>
</ul>
<p>Happy reading.</p>
"""
